from enum import Enum


class PostV1ClaimsClaimIdSubmitResponse200SubmissionQuarantineReasonType0(str, Enum):
    SAFETY_CHECKS = "safety_checks"

    def __str__(self) -> str:
        return str(self.value)
