from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.get_v1_public_jobs_response_200 import GetV1PublicJobsResponse200
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    state: str | Unset = UNSET,
    task_type: str | Unset = UNSET,
    requested_model: str | Unset = UNSET,
    limit: int | Unset = 50,
    cursor: str | Unset = UNSET,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["state"] = state

    params["taskType"] = task_type

    params["requestedModel"] = requested_model

    params["limit"] = limit

    params["cursor"] = cursor

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/v1/public/jobs",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> GetV1PublicJobsResponse200 | None:
    if response.status_code == 200:
        response_200 = GetV1PublicJobsResponse200.from_dict(response.json())

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[GetV1PublicJobsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    state: str | Unset = UNSET,
    task_type: str | Unset = UNSET,
    requested_model: str | Unset = UNSET,
    limit: int | Unset = 50,
    cursor: str | Unset = UNSET,
) -> Response[GetV1PublicJobsResponse200]:
    """
    Args:
        state (str | Unset):
        task_type (str | Unset):
        requested_model (str | Unset):
        limit (int | Unset):  Default: 50.
        cursor (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetV1PublicJobsResponse200]
    """

    kwargs = _get_kwargs(
        state=state,
        task_type=task_type,
        requested_model=requested_model,
        limit=limit,
        cursor=cursor,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient | Client,
    state: str | Unset = UNSET,
    task_type: str | Unset = UNSET,
    requested_model: str | Unset = UNSET,
    limit: int | Unset = 50,
    cursor: str | Unset = UNSET,
) -> GetV1PublicJobsResponse200 | None:
    """
    Args:
        state (str | Unset):
        task_type (str | Unset):
        requested_model (str | Unset):
        limit (int | Unset):  Default: 50.
        cursor (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetV1PublicJobsResponse200
    """

    return sync_detailed(
        client=client,
        state=state,
        task_type=task_type,
        requested_model=requested_model,
        limit=limit,
        cursor=cursor,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    state: str | Unset = UNSET,
    task_type: str | Unset = UNSET,
    requested_model: str | Unset = UNSET,
    limit: int | Unset = 50,
    cursor: str | Unset = UNSET,
) -> Response[GetV1PublicJobsResponse200]:
    """
    Args:
        state (str | Unset):
        task_type (str | Unset):
        requested_model (str | Unset):
        limit (int | Unset):  Default: 50.
        cursor (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetV1PublicJobsResponse200]
    """

    kwargs = _get_kwargs(
        state=state,
        task_type=task_type,
        requested_model=requested_model,
        limit=limit,
        cursor=cursor,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient | Client,
    state: str | Unset = UNSET,
    task_type: str | Unset = UNSET,
    requested_model: str | Unset = UNSET,
    limit: int | Unset = 50,
    cursor: str | Unset = UNSET,
) -> GetV1PublicJobsResponse200 | None:
    """
    Args:
        state (str | Unset):
        task_type (str | Unset):
        requested_model (str | Unset):
        limit (int | Unset):  Default: 50.
        cursor (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetV1PublicJobsResponse200
    """

    return (
        await asyncio_detailed(
            client=client,
            state=state,
            task_type=task_type,
            requested_model=requested_model,
            limit=limit,
            cursor=cursor,
        )
    ).parsed
